/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.it;

import junit.framework.Assert;
import org.jdtaus.core.container.Container;

/**
 * Testcase for {@code Container} implementations.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: ContainerTest.java 3079 2007-04-24 00:35:21Z schulte2005 $
 */
public class ContainerTest
{
    //--ContainerTest-----------------------------------------------------------

    /** The implementation to test. */
    private Container container;

    /**
     * Gets the {@code Container} implementation tests are performed with.
     *
     * @return the {@code Container} implementation tests are performed
     * with.
     */
    public Container getContainer()
    {
        return this.container;
    }

    /**
     * Sets the {@code Container} implementation to test.
     *
     * @param value the {@code Container} implementation to test.
     */
    public final void setContainer(final Container value)
    {
        this.container = value;
    }

    //-----------------------------------------------------------ContainerTest--
    //--Tests-------------------------------------------------------------------

    /**
     * Tests the {@link Container#getImplementation(Class, String)} method
     * to return the correctly initialized instance of
     * {@link TestImplementation}.
     */
    public void testInstantiation() throws Exception
    {
        assert this.getContainer() != null;

        final TestSpecification spec = (TestSpecification) this.getContainer().
            getImplementation(TestSpecification.class, "jDTAUS Core Test Suite");

        Assert.assertTrue(spec.isInitialized());
    }

    /**
     * Tests the {@link Container#getImplementation(Class, String)} method
     * to return the same instance of {@link TestImplementation} for successive
     * calls.
     */
    public void testSingleton() throws Exception
    {
        assert this.getContainer() != null;

        final TestSpecification spec1 = (TestSpecification) this.getContainer().
            getImplementation(TestSpecification.class, "jDTAUS Core Test Suite");

        final TestSpecification spec2 = (TestSpecification) this.getContainer().
            getImplementation(TestSpecification.class, "jDTAUS Core Test Suite");

        final TestSpecification spec3 = (TestSpecification) this.getContainer().
            getImplementation(TestSpecification.class, "jDTAUS Core Test Suite");

        Assert.assertTrue(spec1 == spec2);
        Assert.assertTrue(spec2 == spec3);
        Assert.assertTrue(spec3 == spec1);
    }

    //-------------------------------------------------------------------Tests--
}
